#-*- mode: Fundamental; tab-width: 4; -*-
# ex:ts=4
#
# bsd.mesa.mk - an attempt to refactor MesaLib ports.
#
# Created by: Florent Thoumie <flz@FreeBSD.org>
#
# !!! Here be dragons !!! (they seem to be everywhere these days)
#
# Remember to upgrade the following ports everytime you bump MESAVERSION:
#
#    - graphics/libGL
#    - graphics/libGLU
#    - graphics/dri
#
# $FreeBSD$

.MAKE.FreeBSD_UL=	yes

#??
PORTVERSION=	${MESABASEVERSION}${MESASUBVERSION:C/^(.)/.\1/}
MESAVERSION=	${MESABASEVERSION}${MESASUBVERSION:C/^(.)/.\1/}
MESADISTVERSION=${MESABASEVERSION}${MESASUBVERSION:C/^(.)/-\1/}

.if defined(WITH_NEW_XORG)
MESABASEVERSION=	9.1.3
# if there is a subversion, include the '-' between 7.11-rc2 for example.
MESASUBVERSION=		
PORTREVISION=		0
PLIST_SUB+=	OLD="@comment " NEW=""
.else
MESABASEVERSION=	7.6.1
MESASUBVERSION=		
PORTREVISION=		3
PLIST_SUB+=	OLD="" NEW="@comment "
.endif

MASTER_SITES=	ftp://ftp.freedesktop.org/pub/mesa/${MESABASEVERSION}/
#MASTER_SITES=	LOCAL/kwm
DISTFILES=	MesaLib-${MESADISTVERSION}${EXTRACT_SUFX}
#DISTFILES=	mesa-${MESADISTVERSION}${EXTRACT_SUFX}
MAINTAINER?=	x11@FreeBSD.org

BUILD_DEPENDS+=	makedepend:${PORTSDIR}/devel/makedepend \
		${LOCALBASE}/bin/flex:${PORTSDIR}/textproc/flex \
		${PYTHON_SITELIBDIR}/libxml2.py:${PORTSDIR}/textproc/py-libxml2

USES=	bison pathfix pkgconfig
USE_PYTHON_BUILD=yes
USE_BZIP2=	yes
USE_GMAKE=	yes
USE_LDCONFIG=	yes
GNU_CONFIGURE=	yes
MAKE_JOBS_SAFE=	yes

CPPFLAGS+=	-I${LOCALBASE}/include
LDFLAGS+=	-L${LOCALBASE}/lib
CONFIGURE_ARGS+=--enable-gallium-llvm=no --without-gallium-drivers \
		--disable-egl
CONFIGURE_ARGS+=--disable-silent-rules
CONFIGURE_ENV+=ac_cv_prog_LEX=${LOCALBASE}/bin/flex

.if defined(WITH_NEW_XORG)
EXTRA_PATCHES+=	${PATCHDIR}/extra-configure \
		${PATCHDIR}/extra-src_egl_main_Makefile.in \
		${PATCHDIR}/extra-src__gallium__include__pipe__p_config.h \
		${PATCHDIR}/extra-src_gallium_drivers_r300_r300-chipset.c \
		${PATCHDIR}/extra-src_gallium_drivers_r600_r600-asm.c \
		${PATCHDIR}/extra-src_gallium_drivers_r600_r600-shader.c \
		${PATCHDIR}/extra-src_gallium_drivers_r600_r600_state_common.c \
		${PATCHDIR}/extra-src_gallium_drivers_radeonsi_r600-buffer.c \
		${PATCHDIR}/extra-src_gallium_winsys_svga_drm_vmw-screen-ioctl.c \
		${PATCHDIR}/extra-src-glsl_ir_constant_expression.cpp \
		${PATCHDIR}/extra-src_glx_Makefile.in \
		${PATCHDIR}/extra-src_glx_XF86dri.c \
		${PATCHDIR}/extra-src_mapi_shared-glapi_Makefile.in \
		${PATCHDIR}/extra-src_mesa_drivers_dri_common_xmlpool_Makefile.in \
		${PATCHDIR}/extra-src_mesa_libdricore_Makefile.in \
		${PATCHDIR}/extra-src_mesa_main_compiler.h \
		${PATCHDIR}/extra-src_mesa_drivers_dri_common_Makefile.in

#		${PATCHDIR}/extra-src_mesa_drivers_x11_Makefile.in
.else
EXTRA_PATCHES+=	${PATCHDIR}/extra-configure-old \
		${PATCHDIR}/extra-mach64_context.h-old \
		${PATCHDIR}/extra-src_mesa_Makefile \
		${PATCHDIR}/extra-src__mesa__x86-64__glapi_x86-64.S \
		${PATCHDIR}/extra-src__mesa__x86-64__xform4.S \
		${PATCHDIR}/extra-src__mesa__x86__glapi_x86.S \
		${PATCHDIR}/extra-src__mesa__x86__read_rgba_span_x86.S \
		${PATCHDIR}/extra-src_glx_x11_XF86dri.c
CONFIGURE_ARGS+=--disable-glut --disable-glw
.endif

#ALL_TARGET=		default

MASTERDIR=		${.CURDIR}/../../graphics/libGL
PATCHDIR=		${MASTERDIR}/files
DESCR=			${.CURDIR}/pkg-descr
PLIST=			${.CURDIR}/pkg-plist
WRKSRC=			${WRKDIR}/Mesa-${MESADISTVERSION}

.if !defined(ARCH)
ARCH!=			uname -p
.endif

COMPONENT=		${PORTNAME:L:C/^lib//:C/mesa-//}

.if ${COMPONENT:Mglu} == "" && !defined(WITH_NEW_XORG)
CONFIGURE_ARGS+=	--disable-glu
.endif

.if ${COMPONENT:Mdri} == ""
CONFIGURE_ARGS+=	--with-dri-drivers=no
.else
# done in the dri port
.endif

.if !defined(WITH_NEW_XORG)
.if defined(WITHOUT_XCB)
CONFIGURE_ARGS+=	--disable-xcb
.else
CONFIGURE_ARGS+=	--enable-xcb
.endif
.endif

post-patch:
	@${REINPLACE_CMD} -e 's|-ffast-math|${FAST_MATH}|' -e 's|x86_64|amd64|' \
		${WRKSRC}/configure
.if ! defined(WITH_NEW_XORG)
	@${REINPLACE_CMD} -e 's|[$$](INSTALL_LIB_DIR)/pkgconfig|${PREFIX}/libdata/pkgconfig|' \
		${WRKSRC}/src/glu/Makefile \
		${WRKSRC}/src/mesa/Makefile \
		${WRKSRC}/src/mesa/drivers/dri/Makefile
.endif
# stop autofoo from rerunning and screwing up
	${TOUCH} -t 200001010000 ${WRKSRC}/m4/libtool.m4 ${WRKSRC}/m4/ltoptions.m4 \
		${WRKSRC}/m4/ltsuger.m4 ${WRKSRC}/m4/ltversion.m4 \
		${WRKSRC}/m4/lt~obsolete.m4 ${WRKSRC}/aclocal.m4

#touch: out of range or illegal time specification: [[CC]YY]MMDDhhmm[.SS]
#.if defined(WITH_NEW_XORG)
#. for lang in de es nl fr sv
#	@${MKDIR} ${WRKSRC}/src/mesa/drivers/dri/common/xmlpool/${lang}/LC_MESSAGES/
#. endfor
#.endif

